View Source template_compiler_admin (template_compiler v3.5.0)

Administrate all compiled templates and compilers in flight.

Summary

Functions

Flush all template mappings

Ping that a context has changed

Flush all template mappings for modules compiled with debug points enabled

Flush all template mappings for modules compiled with debug points enabled for a context name

Ping that a template has been changed

Find a template, start a compilation if not found

Functions

code_change(FromVersion, State, Extra)

flush()

-spec flush() -> ok.

Flush all template mappings

flush_context_name(ContextName)

-spec flush_context_name(ContextName :: term()) -> ok.

Ping that a context has changed

flush_debug()

-spec flush_debug() -> ok.

Flush all template mappings for modules compiled with debug points enabled

flush_debug(ContextName)

-spec flush_debug(term()) -> ok.

Flush all template mappings for modules compiled with debug points enabled for a context name

flush_file(Filename)

-spec flush_file(file:filename_all()) -> ok.

Ping that a template has been changed

handle_call(Msg, From, State)

handle_cast(Msg, State)

handle_info(Msg, State)

init(_)

lookup(Filename, Options, Context)

-spec lookup(file:filename_all(), template_compiler:options(), any()) -> {ok, atom()} | {error, term()}.

Find a template, start a compilation if not found

register(Filename, Options, Context, Module)

-spec register(file:filename_all(), template_compiler:options(), any(), atom()) -> ok.

start_link()

-spec start_link() -> {ok, pid()} | {error, any()}.

terminate(Reason, State)