View Source template_compiler_admin (template_compiler v3.5.0)
Administrate all compiled templates and compilers in flight.
Summary
Functions
Flush all template mappings
Ping that a context has changed
Flush all template mappings for modules compiled with debug points enabled
Flush all template mappings for modules compiled with debug points enabled for a context name
Ping that a template has been changed
Find a template, start a compilation if not found
Functions
-spec flush() -> ok.
Flush all template mappings
-spec flush_context_name(ContextName :: term()) -> ok.
Ping that a context has changed
-spec flush_debug() -> ok.
Flush all template mappings for modules compiled with debug points enabled
-spec flush_debug(term()) -> ok.
Flush all template mappings for modules compiled with debug points enabled for a context name
-spec flush_file(file:filename_all()) -> ok.
Ping that a template has been changed
-spec lookup(file:filename_all(), template_compiler:options(), any()) -> {ok, atom()} | {error, term()}.
Find a template, start a compilation if not found
-spec register(file:filename_all(), template_compiler:options(), any(), atom()) -> ok.